# handy-utils


[![pypi](https://img.shields.io/pypi/v/handy-utils.svg)](https://pypi.org/project/handy-utils/)
[![python](https://img.shields.io/pypi/pyversions/handy-utils.svg)](https://pypi.org/project/handy-utils/)
[![Build Status](https://github.com/vempaliakhil96/handy-utils/actions/workflows/dev.yml/badge.svg)](https://github.com/vempaliakhil96/handy-utils/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/vempaliakhil96/handy-utils/graph/badge.svg?token=PP3JT1ED3S)](https://codecov.io/gh/vempaliakhil96/handy-utils)


Simple python package with useful utils.

* Documentation: <https://vempaliakhil96.github.io/handy-utils>
* GitHub: <https://github.com/vempaliakhil96/handy-utils>
* PyPI: <https://pypi.org/project/handy-utils/>
* Free software: MIT


## Features

* LLM based commit message generation
* Custom LLM client with support proxy url
* Setup automated code coverage reporting
* Setup automated code quality checks
* Setup automated deployment to pypi
* Setup automated documentation deployment

